<?php

namespace Drupal\immoweb_api_client\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ImmowebApiClientSettingsForm.
 *
 * Provides all configuration for the Immoweb API Client.
 */
class ImmowebApiClientSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'immoweb_api_client.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'immoweb_api_client_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('immoweb_api_client.settings');

    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID'),
      '#description' => $this->t('The client ID for the authorization request.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('client_id'),
      '#required' => TRUE,
    ];

    $form['client_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client Secret'),
      '#description' => $this->t('The client Secret for the authorization request.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('client_secret'),
      '#required' => TRUE,
    ];

    $form['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#description' => $this->t('The username for the authorization request.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $config->get('username'),
      '#required' => TRUE,
    ];

    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#description' => $this->t('The password for the authorization request.'),
      '#maxlength' => 64,
      '#size' => 64,
      '#required' => TRUE,
    ];

    $form['target_server'] = [
      '#type' => 'radios',
      '#title' => $this->t('Target Server'),
      '#description' => $this->t('The target server you want to connect to. Useful when developing your integration.'),
      '#options' => [
        'DEV' => $this->t('DEV Environment'),
        'TEST' => $this->t('TEST Environment'),
        'PROD' => $this->t('PROD Environment'),
      ],
      '#default_value' => $config->get('target_server') ?: 'DEV',
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('immoweb_api_client.settings')
      ->set('client_id', $form_state->getValue('client_id'))
      ->set('client_secret', $form_state->getValue('client_secret'))
      ->set('username', $form_state->getValue('username'))
      ->set('password', $form_state->getValue('password'))
      ->set('target_server', $form_state->getValue('target_server'))
      ->save();
  }

}
