<?php

namespace Drupal\immoweb_api_client\Resource\Classified;

use Drupal\Component\Serialization\Json;
use Psr\Http\Message\ResponseInterface;

/**
 * Class ClassifiedCreate.
 *
 * Class containing all the logic to create a classified.
 *
 * @package Drupal\immoweb_api_client\Resource\Classified
 */
class ClassifiedCreate extends ClassifiedRequestBase implements ClassifiedCreateInterface {

  /**
   * {@inheritdoc}
   */
  public function createClassified(array $body): ?ResponseInterface {
    // @todo: Validate the actual schema/content of the body.
    // Validation.
    if (!$this->validateParameters(['not_empty'], $body)) {
      $this->logger->error($this->t('Not all required parameters passed validation.'));
      return NULL;
    }

    // Make the request.
    try {
      return $this->httpClient->request(
        'POST',
        $this->getBaseUrl(),
        [
          'form_params' => Json::encode($body),
          'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => $this->authenticator->getToken(),
            'x-iw-api-key' => $this->config->get('api_key'),
          ],
        ]
      );
    }
    catch (\Exception $exception) {
      $this->logger->error($exception->getMessage());
      return NULL;
    }
  }

}
